@@ -119,18 +119,38 @@ def gensolution(script_path, config, inports, outports, override_readme = False,
     with open(script_path, 'r') as read_fn:
         with open(os.path.join(operator_solution_path, script_filename), 'w') as write_fn:
             line = read_fn.readline()
+
+            exclude_section = False
             while line :
+                if re.match('try:',line) :
+                    exclude_section = True
+                    line = read_fn.readline()
+                    continue
+                if re.match('except NameError:',line) :
+                    line = read_fn.readline()
+                    continue
+                if exclude_section and re.match('[\w#]+',line)  :
+                    exclude_section = False
+
+                # activate call function
                 line = re.sub(r'^#\s*api.set_port_callback', 'api.set_port_callback', line)
                 line = re.sub(r'^#\s*api.add_generator', 'api.add_generator', line)
                 line = re.sub(r'^#\s*api.add_timer', 'api.add_timer', line)
                 line = re.sub(r'^#\s*api.add_shutdown_handler', 'api.add_shutdown_handler', line)
-                if re.match(r'if __name__ == \'__main__\'',line) or re.match(r'if __name__ == \"__main__\"',line) :
+
+                # remove unnecessary imports
+                if re.match(r'import subprocess',line) or re.match(r'import sdi_utils.gensolution as gs',line) :
+                    line = read_fn.readline()
+                    continue
+
+                # end of important part
+                if re.match(r'if __name__ == \'__main__\'',line) or re.match(r'if __name__ == \"__main__\"',line) or \
+                   re.match(r'def test_operator()',line):
                     break
-                #if re.match(r'import sdi_utils',line) :
-                #    line = read_fn.readline()
-                #    continue
+
                 write_fn.write(line)
                 line = read_fn.readline()
+
         write_fn.close()
     read_fn.close()
 
