@@ -11,11 +11,6 @@ def split_text(text,sep) :
     sep_indices = [m.start() for m in re.finditer(sep, text)]
     quote_indices = [m.start() for m in re.finditer("'", text) if m.start() == 0 or text[m.start()-1] != '\\' ]
 
-    if sep == ',' :
-        print('\nSPLIT text for: {} - {} '.format(sep,text))
-        for q in quote_indices :
-            print(text[q-1:])
-
     list_seps = list()
     for s_index in sep_indices :
         if not len([ mi for mi in quote_indices if mi < s_index]) % 2 :
@@ -29,7 +24,10 @@ def split_text(text,sep) :
         else :
             list_texts.append(text[last_index+1:s_index].strip())
         last_index = s_index
-    list_texts.append(text[last_index + 1:].strip())
+    if last_index == 0 :
+        list_texts.append(text[:].strip())
+    else:
+        list_texts.append(text[last_index + 1:].strip())
 
     return list_texts
 
