@@ -1,12 +1,10 @@
 import io
-import json
 import os
-import re
 import csv
 import subprocess
 
 import sdi_utils.gensolution as gs
-import sdi_utils.set_logging as slog
+import deprecated.set_logging as slog
 import sdi_utils.textfield_parser as tfp
 import sdi_utils.tprogress as tp
 
@@ -139,7 +137,7 @@ def test_operator() :
 
 
 if __name__ == '__main__':
-    test_operator()
+    #test_operator()
     if True :
         gs.gensolution(os.path.realpath(__file__), api.config, inports, outports)
         solution_name = api.config.operator_name+'_'+api.config.version
