@@ -1,11 +1,9 @@
 import io
-import json
 import os
 import subprocess
 
 import sdi_utils.gensolution as gs
-import sdi_utils.set_logging as slog
-import sdi_utils.textfield_parser as tfp
+import deprecated.set_logging as slog
 import sdi_utils.tprogress as tp
 
 try:
@@ -107,7 +105,7 @@ outports = [{'name': 'log', 'type': 'string',"description":"Logging data"}, \
 
 #api.set_port_callback(inports[0]['name'], process)
 
-def main() :
+def test_operator() :
     config = api.config
     config.debug_mode = True
     config.collect = False
@@ -124,11 +122,13 @@ def main() :
 
 
 if __name__ == '__main__':
-    main()
+    #test_operator()
     if True :
+        subprocess.run(["rm", '-r',
+                        '/Users/d051079/OneDrive - SAP SE/GitHub/sdi_utils/solution/operators/sdi_utils_operators' + api.config.version])
         gs.gensolution(os.path.realpath(__file__), api.config, inports, outports)
-        solution_name = api.config.operator_name+'_'+api.config.version
-
-        subprocess.run(["vctl", "solution", "bundle", '/Users/d051079/OneDrive - SAP SE/GitHub/sdi_utils/solution/operators/sdi_utils_operators_0.0.1',\
-                                  "-t", solution_name])
-        subprocess.run(["mv", solution_name+'.zip', '../../../solution/operators'])
\ No newline at end of file
+        solution_name = api.config.operator_name + '_' + api.config.version
+        subprocess.run(["vctl", "solution", "bundle",
+                        '/Users/d051079/OneDrive - SAP SE/GitHub/sdi_utils/solution/operators/sdi_utils_operators_' + api.config.version, \
+                        "-t", solution_name])
+        subprocess.run(["mv", solution_name + '.zip', '../../../solution/operators'])
